@@ -121,7 +121,7 @@ BatchProcessImagesDialog::BatchProcessImagesDialog( KURL::List urlList, KIPI::In
     //---------------------------------------------
 
     TQHBoxLayout *hlay = new TQHBoxLayout( dvlay );
-    groupBox1 = new TQGroupBox( 0, Qt::Vertical, box );
+    groupBox1 = new TQGroupBox( 0, TQt::Vertical, box );
     groupBox1->layout()->setSpacing(KDialog::spacingHint());
     groupBox1->layout()->setMargin(KDialog::marginHint());
     TQGridLayout* grid = new TQGridLayout( groupBox1->layout(), 2, 3);
@@ -155,7 +155,7 @@ BatchProcessImagesDialog::BatchProcessImagesDialog( KURL::List urlList, KIPI::In
 
     //---------------------------------------------
 
-    groupBox2 = new TQGroupBox( 2, Qt::Horizontal, i18n("File Operations"), box );
+    groupBox2 = new TQGroupBox( 2, TQt::Horizontal, i18n("File Operations"), box );
 
     m_labelOverWrite = new TQLabel (i18n("Overwrite mode:"), groupBox2);
     m_overWriteMode = new TQComboBox( false, groupBox2 );
@@ -239,32 +239,32 @@ BatchProcessImagesDialog::BatchProcessImagesDialog( KURL::List urlList, KIPI::In
 
     //---------------------------------------------
 
-    connect(m_listFiles, TQT_SIGNAL(doubleClicked(TQListViewItem *)),
-            this, TQT_SLOT(slotListDoubleClicked(TQListViewItem *)));
+    connect(m_listFiles, TQ_SIGNAL(doubleClicked(TQListViewItem *)),
+            this, TQ_SLOT(slotListDoubleClicked(TQListViewItem *)));
 
-    connect(this, TQT_SIGNAL(user1Clicked()),
-            this, TQT_SLOT(slotProcessStart()));
+    connect(this, TQ_SIGNAL(user1Clicked()),
+            this, TQ_SLOT(slotProcessStart()));
 
-    connect(m_optionsButton, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotOptionsClicked()));
+    connect(m_optionsButton, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotOptionsClicked()));
 
-    connect(m_previewButton, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotPreview()));
+    connect(m_previewButton, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotPreview()));
 
-    connect(m_Type, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotTypeChanged(int)));
+    connect(m_Type, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotTypeChanged(int)));
 
-    connect(m_listFiles, TQT_SIGNAL( addedDropItems(TQStringList) ),
-            this, TQT_SLOT( slotAddDropItems(TQStringList)));
+    connect(m_listFiles, TQ_SIGNAL( addedDropItems(TQStringList) ),
+            this, TQ_SLOT( slotAddDropItems(TQStringList)));
 
-    connect(m_listFiles, TQT_SIGNAL( currentChanged( TQListViewItem * ) ),
-            this, TQT_SLOT( slotImageSelected( TQListViewItem * )));
+    connect(m_listFiles, TQ_SIGNAL( currentChanged( TQListViewItem * ) ),
+            this, TQ_SLOT( slotImageSelected( TQListViewItem * )));
 
-    connect(m_addImagesButton, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotImagesFilesButtonAdd()));
+    connect(m_addImagesButton, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotImagesFilesButtonAdd()));
 
-    connect(m_remImagesButton, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotImagesFilesButtonRem()));
+    connect(m_remImagesButton, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotImagesFilesButtonRem()));
 
    // Get the image files filters from the hosts app.
 
@@ -329,8 +329,8 @@ void BatchProcessImagesDialog::slotImageSelected( TQListViewItem * item )
 
     TDEIO::PreviewJob* m_thumbJob = TDEIO::filePreview( url, m_imageLabel->height() );
 
-    connect(m_thumbJob, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
-            this, TQT_SLOT(slotGotPreview(const KFileItem*, const TQPixmap&)));
+    connect(m_thumbJob, TQ_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
+            this, TQ_SLOT(slotGotPreview(const KFileItem*, const TQPixmap&)));
 }
 
 void BatchProcessImagesDialog::slotGotPreview(const KFileItem* url, const TQPixmap &pixmap)
@@ -407,10 +407,10 @@ void BatchProcessImagesDialog::slotProcessStart( void )
     }
 
     m_convertStatus = UNDER_PROCESS;
-    disconnect( this, TQT_SIGNAL(user1Clicked()), this, TQT_SLOT(slotProcessStart()));
+    disconnect( this, TQ_SIGNAL(user1Clicked()), this, TQ_SLOT(slotProcessStart()));
     showButtonCancel( false );
     setButtonText( User1, i18n("&Stop") );
-    connect(this, TQT_SIGNAL(user1Clicked()), this, TQT_SLOT(slotProcessStop()));
+    connect(this, TQ_SIGNAL(user1Clicked()), this, TQ_SLOT(slotProcessStop()));
 
     m_labelType->setEnabled(false);
     m_Type->setEnabled(false);
@@ -476,7 +476,7 @@ bool BatchProcessImagesDialog::startProcess(void)
     KURL desturl(targetAlbum + "/" + item->nameDest());
 
 #if TDE_VERSION >= 0x30200
-    if ( TDEIO::NetAccess::exists( desturl, false, TQT_TQWIDGET(kapp->activeWindow()) ) == true )
+    if ( TDEIO::NetAccess::exists( desturl, false, kapp->activeWindow() ) == true )
 #else
     if ( TDEIO::NetAccess::exists( desturl ) == true )
 #endif
@@ -595,14 +595,14 @@ bool BatchProcessImagesDialog::startProcess(void)
 
     item->changeOutputMess(m_commandLine + "\n\n");
 
-    connect(m_ProcessusProc, TQT_SIGNAL(processExited(TDEProcess *)),
-            this, TQT_SLOT(slotProcessDone(TDEProcess*)));
+    connect(m_ProcessusProc, TQ_SIGNAL(processExited(TDEProcess *)),
+            this, TQ_SLOT(slotProcessDone(TDEProcess*)));
 
-    connect(m_ProcessusProc, TQT_SIGNAL(receivedStdout(TDEProcess *, char*, int)),
-            this, TQT_SLOT(slotReadStd(TDEProcess*, char*, int)));
+    connect(m_ProcessusProc, TQ_SIGNAL(receivedStdout(TDEProcess *, char*, int)),
+            this, TQ_SLOT(slotReadStd(TDEProcess*, char*, int)));
 
-    connect(m_ProcessusProc, TQT_SIGNAL(receivedStderr(TDEProcess *, char*, int)),
-            this, TQT_SLOT(slotReadStd(TDEProcess*, char*, int)));
+    connect(m_ProcessusProc, TQ_SIGNAL(receivedStderr(TDEProcess *, char*, int)),
+            this, TQ_SLOT(slotReadStd(TDEProcess*, char*, int)));
 
     bool result = m_ProcessusProc->start(TDEProcess::NotifyOnExit, TDEProcess::All);
     if(!result)
@@ -715,7 +715,7 @@ void BatchProcessImagesDialog::slotProcessDone(TDEProcess* proc)
                 KURL deleteImage(item->pathSrc());
     
 #if TDE_VERSION >= 0x30200
-                if ( TDEIO::NetAccess::del( deleteImage, TQT_TQWIDGET(kapp->activeWindow()) ) == false )
+                if ( TDEIO::NetAccess::del( deleteImage, kapp->activeWindow() ) == false )
 #else
                 if ( TDEIO::NetAccess::del( deleteImage ) == false )
 #endif
@@ -792,14 +792,14 @@ void BatchProcessImagesDialog::slotPreview(void)
     m_addImagesButton->setEnabled(false);
     m_remImagesButton->setEnabled(false);
 
-    disconnect( this, TQT_SIGNAL(user1Clicked()),
-                this, TQT_SLOT(slotProcessStart()));
+    disconnect( this, TQ_SIGNAL(user1Clicked()),
+                this, TQ_SLOT(slotProcessStart()));
 
     showButtonCancel( false );
     setButtonText( User1, i18n("&Stop") );
 
-    connect(this, TQT_SIGNAL(user1Clicked()),
-            this, TQT_SLOT(slotPreviewStop()));
+    connect(this, TQ_SIGNAL(user1Clicked()),
+            this, TQ_SLOT(slotPreviewStop()));
 
     m_previewOutput = "";
     m_PreviewProc = new TDEProcess;
@@ -809,14 +809,14 @@ void BatchProcessImagesDialog::slotPreview(void)
     *m_PreviewProc << m_tmpFolder + "/" + TQString::number(getpid()) + "preview.PNG";
     m_previewOutput.append( " "  + m_tmpFolder + "/" + TQString::number(getpid()) + "preview.PNG\n\n");
 
-    connect(m_PreviewProc, TQT_SIGNAL(processExited(TDEProcess *)),
-            this, TQT_SLOT(slotPreviewProcessDone(TDEProcess*)));
+    connect(m_PreviewProc, TQ_SIGNAL(processExited(TDEProcess *)),
+            this, TQ_SLOT(slotPreviewProcessDone(TDEProcess*)));
 
-    connect(m_PreviewProc, TQT_SIGNAL(receivedStdout(TDEProcess *, char*, int)),
-            this, TQT_SLOT(slotPreviewReadStd(TDEProcess*, char*, int)));
+    connect(m_PreviewProc, TQ_SIGNAL(receivedStdout(TDEProcess *, char*, int)),
+            this, TQ_SLOT(slotPreviewReadStd(TDEProcess*, char*, int)));
 
-    connect(m_PreviewProc, TQT_SIGNAL(receivedStderr(TDEProcess *, char*, int)),
-            this, TQT_SLOT(slotPreviewReadStd(TDEProcess*, char*, int)));
+    connect(m_PreviewProc, TQ_SIGNAL(receivedStderr(TDEProcess *, char*, int)),
+            this, TQ_SLOT(slotPreviewReadStd(TDEProcess*, char*, int)));
 
     bool result = m_PreviewProc->start(TDEProcess::NotifyOnExit, TDEProcess::All);
     if(!result)
@@ -868,7 +868,7 @@ void BatchProcessImagesDialog::slotPreviewProcessDone(TDEProcess* proc)
        KURL deletePreviewImage(m_tmpFolder + "/" + TQString::number(getpid()) + "preview.PNG");
 
 #if TDE_VERSION >= 0x30200
-       TDEIO::NetAccess::del( deletePreviewImage, TQT_TQWIDGET(kapp->activeWindow()) );
+       TDEIO::NetAccess::del( deletePreviewImage, kapp->activeWindow() );
 #else
        TDEIO::NetAccess::del( deletePreviewImage );
 #endif
@@ -987,11 +987,11 @@ void BatchProcessImagesDialog::endPreview(void)
 
     setButtonText( User1, i18n("&Start") );
 
-    disconnect(this, TQT_SIGNAL(user1Clicked()),
-               this, TQT_SLOT(slotPreviewStop()));
+    disconnect(this, TQ_SIGNAL(user1Clicked()),
+               this, TQ_SLOT(slotPreviewStop()));
 
-    connect(this, TQT_SIGNAL(user1Clicked()),
-            this, TQT_SLOT(slotProcessStart()));
+    connect(this, TQ_SIGNAL(user1Clicked()),
+            this, TQ_SLOT(slotProcessStart()));
 }
 
 int BatchProcessImagesDialog::overwriteMode(void)
@@ -1029,8 +1029,8 @@ void BatchProcessImagesDialog::processAborted(bool removeFlag)
        deleteImage.addPath(item->nameDest());
 
 #if TDE_VERSION >= 0x30200
-       if ( TDEIO::NetAccess::exists( deleteImage, false, TQT_TQWIDGET(kapp->activeWindow()) ) == true )
-          TDEIO::NetAccess::del( deleteImage, TQT_TQWIDGET(kapp->activeWindow()) );
+       if ( TDEIO::NetAccess::exists( deleteImage, false, kapp->activeWindow() ) == true )
+          TDEIO::NetAccess::del( deleteImage, kapp->activeWindow() );
 #else
        if ( TDEIO::NetAccess::exists( deleteImage ) == true )
           TDEIO::NetAccess::del( deleteImage );
@@ -1045,11 +1045,11 @@ void BatchProcessImagesDialog::endProcess(void)
     m_convertStatus = PROCESS_DONE;
     setButtonText( User1, i18n("&Close") );
 
-    disconnect(this, TQT_SIGNAL(user1Clicked()),
-               this, TQT_SLOT(slotProcessStop()));
+    disconnect(this, TQ_SIGNAL(user1Clicked()),
+               this, TQ_SLOT(slotProcessStop()));
 
-    connect(this, TQT_SIGNAL(user1Clicked()),
-            this, TQT_SLOT(slotOk()));
+    connect(this, TQ_SIGNAL(user1Clicked()),
+            this, TQ_SLOT(slotOk()));
 }
 
 TQString BatchProcessImagesDialog::RenameTargetImageFile(TQFileInfo *fi)
@@ -1067,7 +1067,7 @@ TQString BatchProcessImagesDialog::RenameTargetImageFile(TQFileInfo *fi)
     }
     while ( Enumerator < 100 &&
 #if TDE_VERSION >= 0x30200
-            TDEIO::NetAccess::exists( NewDestUrl, true, TQT_TQWIDGET(kapp->activeWindow()) )
+            TDEIO::NetAccess::exists( NewDestUrl, true, kapp->activeWindow() )
 #else
             TDEIO::NetAccess::exists( NewDestUrl )
 #endif
