@@ -209,7 +209,7 @@ bool CDArchiving::showDialog()
     m_HTMLInterfaceAutoRunInf = "";
     m_HTMLInterfaceAutoRunFolder = "";
 
-    m_configDlg = new CDArchivingDialog( m_interface, TQT_TQWIDGET(kapp->activeWindow()) );
+    m_configDlg = new CDArchivingDialog( m_interface, kapp->activeWindow() );
     readSettings();
 
     if ( m_configDlg->exec() == TQDialog::Accepted )
@@ -406,8 +406,8 @@ void CDArchiving::invokeK3b()
                              m_tmpFolder + "/KIPICDArchiving.xml";
     kdDebug(51000) << "K3b is started : " << K3bCommandLine.ascii() << endl;
 
-    connect(m_Proc, TQT_SIGNAL(processExited(TDEProcess *)),
-            this, TQT_SLOT(slotK3bDone(TDEProcess*)));
+    connect(m_Proc, TQ_SIGNAL(processExited(TDEProcess *)),
+            this, TQ_SLOT(slotK3bDone(TDEProcess*)));
 
     if ( !m_Proc->start(TDEProcess::NotifyOnExit, TDEProcess::All ) )
     {
@@ -426,7 +426,7 @@ void CDArchiving::invokeK3b()
     if ( m_useStartBurningProcess == true )
     {
         TQTimer::singleShot(10000,
-                           this, TQT_SLOT(slotK3bStartBurningProcess()));
+                           this, TQ_SLOT(slotK3bStartBurningProcess()));
         m_k3bPid = m_Proc->pid();
     }
 }
