@@ -84,8 +84,8 @@ FlickrTalker::FlickrTalker(TQWidget* parent)
     m_apikey = "49d585bafa0758cb5c58ab67198bf632";
     m_secret = "34b39925e6273ffd";
 
-    connect(this, TQT_SIGNAL(signalAuthenticate()),
-            this, TQT_SLOT(slotAuthenticate()));
+    connect(this, TQ_SIGNAL(signalAuthenticate()),
+            this, TQ_SLOT(slotAuthenticate()));
 }
 
 FlickrTalker::~FlickrTalker()
@@ -134,11 +134,11 @@ void FlickrTalker::getFrob()
 
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
 
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            this, TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            this, TQ_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_GETFROB;
     m_authProgressDlg->setLabelText(i18n("Getting the Frob"));
@@ -168,11 +168,11 @@ void FlickrTalker::checkToken(const TQString& token)
 
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
 
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            this, TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            this, TQ_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_CHECKTOKEN;
     m_authProgressDlg->setLabelText(i18n("Checking if previous token is still valid"));
@@ -199,7 +199,7 @@ void FlickrTalker::slotAuthenticate()
     kdDebug() << "Authenticate url: " << url << endl;
 
     TDEApplication::kApplication()->invokeBrowser(url.url());
-    int valueOk = KMessageBox::questionYesNo(TQT_TQWIDGET(kapp->activeWindow()),
+    int valueOk = KMessageBox::questionYesNo(kapp->activeWindow(),
                   i18n("Please Follow through the instructions in the browser window and "
                        "return back to press ok if you are authenticated or press No"),
                   i18n("Flickr Service Web Authorization"));
@@ -237,11 +237,11 @@ void FlickrTalker::getToken()
     TDEIO::TransferJob* job = TDEIO::http_post(url, tmp, false);
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
 
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            this, TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            this, TQ_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_GETTOKEN;
     m_job   = job;
@@ -264,11 +264,11 @@ void FlickrTalker::listPhotoSets()
     TDEIO::TransferJob* job = TDEIO::http_post(url, tmp, false);
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );
 
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            this, TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            this, TQ_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_LISTPHOTOSETS;
     m_job   = job;
@@ -302,11 +302,11 @@ void FlickrTalker::getPhotoProperty(const TQString& method, const TQStringList&
     TDEIO::TransferJob* job = TDEIO::http_post(url, tmp, false);
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );
 
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            this, TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            this, TQ_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_GETPHOTOPROPERTY;
     m_job   = job;
@@ -436,11 +436,11 @@ bool FlickrTalker::addPhoto(const TQString& photoPath, const FPhotoInfo& info,
     TDEIO::TransferJob* job = TDEIO::http_post(url, form.formData(), false);
     job->addMetaData("content-type", form.contentType());
 
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            this, TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            this, TQ_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_ADDPHOTO;
     m_job   = job;
@@ -541,7 +541,7 @@ void FlickrTalker::slotError(const TQString& error)
             break;
     };
 
-    KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()),
+    KMessageBox::error(kapp->activeWindow(),
                  i18n("Error Occured: %1\n We can not proceed further").arg(transError));
 
 //  kdDebug() << "Not handling the error now will see it later" << endl;
@@ -716,7 +716,7 @@ void FlickrTalker::parseResponseCheckToken(const TQByteArray& data)
             kdDebug() << "Error code=" << errorString << endl;
             kdDebug() << "Msg=" << node.toElement().attribute("msg") << endl;
 
-            int valueOk = KMessageBox::questionYesNo(TQT_TQWIDGET(kapp->activeWindow()),
+            int valueOk = KMessageBox::questionYesNo(kapp->activeWindow(),
                                        i18n("Your token is invalid. Would you like to "
                                             "get a new token to proceed ?\n"));
             if(valueOk == KMessageBox::Yes)
