@@ -44,9 +44,9 @@
 
 // KDE includes.
 
-#include <klocale.h>
-#include <kdeversion.h>
-#include <kglobalsettings.h>
+#include <tdelocale.h>
+#include <tdeversion.h>
+#include <tdeglobalsettings.h>
 #include <kdebug.h>
 #include <kurl.h>
 
@@ -63,7 +63,7 @@ SlideShow::SlideShow(const FileList& fileList, const TQStringList& commentsList,
          : TQWidget(0, 0, WStyle_StaysOnTop | WType_Popup | WX11BypassWM | WDestructiveClose)
 {
 #if KDE_IS_VERSION(3,2,0)
-    TQRect deskRect = KGlobalSettings::desktopGeometry(this);
+    TQRect deskRect = TDEGlobalSettings::desktopGeometry(this);
     m_deskX      = deskRect.x();
     m_deskY      = deskRect.y();
     m_deskWidth  = deskRect.width();
@@ -86,20 +86,20 @@ SlideShow::SlideShow(const FileList& fileList, const TQStringList& commentsList,
     {
         m_toolBar->setEnabledPrev(false);
     }
-    connect(m_toolBar, TQT_SIGNAL(signalPause()),
-            this, TQT_SLOT(slotPause()));
+    connect(m_toolBar, TQ_SIGNAL(signalPause()),
+            this, TQ_SLOT(slotPause()));
 
-    connect(m_toolBar, TQT_SIGNAL(signalPlay()),
-            this, TQT_SLOT(slotPlay()));
+    connect(m_toolBar, TQ_SIGNAL(signalPlay()),
+            this, TQ_SLOT(slotPlay()));
 
-    connect(m_toolBar, TQT_SIGNAL(signalNext()),
-            this, TQT_SLOT(slotNext()));
+    connect(m_toolBar, TQ_SIGNAL(signalNext()),
+            this, TQ_SLOT(slotNext()));
 
-    connect(m_toolBar, TQT_SIGNAL(signalPrev()),
-            this, TQT_SLOT(slotPrev()));
+    connect(m_toolBar, TQ_SIGNAL(signalPrev()),
+            this, TQ_SLOT(slotPrev()));
 
-    connect(m_toolBar, TQT_SIGNAL(signalClose()),
-            this, TQT_SLOT(slotClose()));
+    connect(m_toolBar, TQ_SIGNAL(signalClose()),
+            this, TQ_SLOT(slotClose()));
 
     // ---------------------------------------------------------------
     
@@ -111,8 +111,8 @@ SlideShow::SlideShow(const FileList& fileList, const TQStringList& commentsList,
     m_endOfShow     = false;
 
     m_timer = new TQTimer();
-    connect(m_timer, TQT_SIGNAL(timeout()), 
-            this, TQT_SLOT(slotTimeOut()));
+    connect(m_timer, TQ_SIGNAL(timeout()), 
+            this, TQ_SLOT(slotTimeOut()));
 
     // --------------------------------------------------
 
@@ -120,7 +120,7 @@ SlideShow::SlideShow(const FileList& fileList, const TQStringList& commentsList,
     m_commentsList      = commentsList;
     m_ImagesHasComments = ImagesHasComments; 
 
-    m_config = new KConfig("kipirc");
+    m_config = new TDEConfig("kipirc");
     m_config->setGroup("SlideShow Settings");
 
     readSettings();
@@ -147,8 +147,8 @@ SlideShow::SlideShow(const FileList& fileList, const TQStringList& commentsList,
     // -- hide cursor when not moved --------------------
 
     m_mouseMoveTimer = new TQTimer;
-    connect(m_mouseMoveTimer, TQT_SIGNAL(timeout()),
-            TQT_SLOT(slotMouseMoveTimeOut()));
+    connect(m_mouseMoveTimer, TQ_SIGNAL(timeout()),
+            TQ_SLOT(slotMouseMoveTimeOut()));
     
     setMouseTracking(true);
     slotMouseMoveTimeOut();
@@ -591,13 +591,13 @@ void SlideShow::mousePressEvent(TQMouseEvent *e)
     if (m_endOfShow)
         slotClose();
 
-    if (e->button() == Qt::LeftButton)
+    if (e->button() == TQt::LeftButton)
     {
         m_timer->stop();
         m_toolBar->setPaused(true);
         slotNext();
     }
-    else if (e->button() == Qt::RightButton && m_fileIndex-1 >= 0)
+    else if (e->button() == TQt::RightButton && m_fileIndex-1 >= 0)
     {
         m_timer->stop();
         m_toolBar->setPaused(true);
