@@ -94,7 +94,7 @@ SlideShowConfig::SlideShowConfig(bool allowSelectedOnly, KIPI::Interface * inter
 
     KHelpMenu* helpMenu = new KHelpMenu(this, about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQT_SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQ_SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 
     // Switch to selected files only (it depends on allowSelectedOnly)
@@ -113,31 +113,31 @@ SlideShowConfig::SlideShowConfig(bool allowSelectedOnly, KIPI::Interface * inter
     
     // Signal to Slot connections
 
-    connect(m_openglCheckBox, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotOpenGLToggled()));
-    connect(m_buttonStart, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotStartClicked()));
-    connect(m_printCommentsCheckBox, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotPrintCommentsToggled()));
-    connect(m_commentsFontColor, TQT_SIGNAL(changed(const TQColor &)), this, TQT_SLOT(slotCommentsFontColorChanged()));
-    connect(m_commentsBgColor, TQT_SIGNAL(changed(const TQColor &)), this, TQT_SLOT(slotCommentsBgColorChanged()));
-    connect(m_useMillisecondsCheckBox, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotUseMillisecondsToggled()));
-    connect(m_delaySpinBox, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(slotDelayChanged()));
-    connect(m_effectsComboBox, TQT_SIGNAL(activated(int)), this,  TQT_SLOT(slotEffectChanged()));
+    connect(m_openglCheckBox, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotOpenGLToggled()));
+    connect(m_buttonStart, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotStartClicked()));
+    connect(m_printCommentsCheckBox, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotPrintCommentsToggled()));
+    connect(m_commentsFontColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(slotCommentsFontColorChanged()));
+    connect(m_commentsBgColor, TQ_SIGNAL(changed(const TQColor &)), this, TQ_SLOT(slotCommentsBgColorChanged()));
+    connect(m_useMillisecondsCheckBox, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotUseMillisecondsToggled()));
+    connect(m_delaySpinBox, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotDelayChanged()));
+    connect(m_effectsComboBox, TQ_SIGNAL(activated(int)), this,  TQ_SLOT(slotEffectChanged()));
 
-    connect(m_fileSrcButtonGroup, TQT_SIGNAL(clicked(int)), this, TQT_SLOT(slotSelection()));
+    connect(m_fileSrcButtonGroup, TQ_SIGNAL(clicked(int)), this, TQ_SLOT(slotSelection()));
 
-    connect( m_ImagesFilesListBox, TQT_SIGNAL( currentChanged( TQListBoxItem * ) ),
-             this, TQT_SLOT( slotImagesFilesSelected(TQListBoxItem *) ) );
-    connect(m_ImagesFilesListBox, TQT_SIGNAL( addedDropItems(KURL::List) ),
-            this, TQT_SLOT( slotAddDropItems(KURL::List)));
-    connect( m_ImagesFilesButtonAdd, TQT_SIGNAL( clicked() ),
-             this, TQT_SLOT( slotImagesFilesButtonAdd() ) );
-    connect( m_ImagesFilesButtonDelete, TQT_SIGNAL( clicked() ),
-             this, TQT_SLOT( slotImagesFilesButtonDelete() ) );
-    connect( m_ImagesFilesButtonUp, TQT_SIGNAL( clicked() ),
-             this, TQT_SLOT( slotImagesFilesButtonUp() ) );
-    connect( m_ImagesFilesButtonDown, TQT_SIGNAL( clicked() ),
-             this, TQT_SLOT( slotImagesFilesButtonDown() ) );
+    connect( m_ImagesFilesListBox, TQ_SIGNAL( currentChanged( TQListBoxItem * ) ),
+             this, TQ_SLOT( slotImagesFilesSelected(TQListBoxItem *) ) );
+    connect(m_ImagesFilesListBox, TQ_SIGNAL( addedDropItems(KURL::List) ),
+            this, TQ_SLOT( slotAddDropItems(KURL::List)));
+    connect( m_ImagesFilesButtonAdd, TQ_SIGNAL( clicked() ),
+             this, TQ_SLOT( slotImagesFilesButtonAdd() ) );
+    connect( m_ImagesFilesButtonDelete, TQ_SIGNAL( clicked() ),
+             this, TQ_SLOT( slotImagesFilesButtonDelete() ) );
+    connect( m_ImagesFilesButtonUp, TQ_SIGNAL( clicked() ),
+             this, TQ_SLOT( slotImagesFilesButtonUp() ) );
+    connect( m_ImagesFilesButtonDown, TQ_SIGNAL( clicked() ),
+             this, TQ_SLOT( slotImagesFilesButtonDown() ) );
     
-    connect(m_cacheCheckBox, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotCacheToggled()));
+    connect(m_cacheCheckBox, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotCacheToggled()));
     
     m_thumbJob = 0L;
     
@@ -609,10 +609,10 @@ void SlideShowConfig::slotImagesFilesSelected( TQListBoxItem *item )
 
     m_thumbJob = TDEIO::filePreview( url, m_ImageLabel->width() );
 
-    connect(m_thumbJob, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
-            TQT_SLOT(slotGotPreview(const KFileItem*, const TQPixmap&)));
-    connect(m_thumbJob, TQT_SIGNAL(failed(const KFileItem*)),
-            TQT_SLOT(slotFailedPreview(const KFileItem*)));
+    connect(m_thumbJob, TQ_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
+            TQ_SLOT(slotGotPreview(const KFileItem*, const TQPixmap&)));
+    connect(m_thumbJob, TQ_SIGNAL(failed(const KFileItem*)),
+            TQ_SLOT(slotFailedPreview(const KFileItem*)));
 
     int index = m_ImagesFilesListBox->index ( item );
     m_label7->setText(i18n("Image no. %1").arg(index + 1));
