@@ -75,16 +75,16 @@ SlideShowGL::SlideShowGL(const TQValueList<TQPair<TQString, int> >& fileList,
     {
         m_toolBar->setEnabledPrev(false);
     }
-    connect(m_toolBar, TQT_SIGNAL(signalPause()),
-            TQT_SLOT(slotPause()));
-    connect(m_toolBar, TQT_SIGNAL(signalPlay()),
-            TQT_SLOT(slotPlay()));
-    connect(m_toolBar, TQT_SIGNAL(signalNext()),
-            TQT_SLOT(slotNext()));
-    connect(m_toolBar, TQT_SIGNAL(signalPrev()),
-            TQT_SLOT(slotPrev()));
-    connect(m_toolBar, TQT_SIGNAL(signalClose()),
-            TQT_SLOT(slotClose()));
+    connect(m_toolBar, TQ_SIGNAL(signalPause()),
+            TQ_SLOT(slotPause()));
+    connect(m_toolBar, TQ_SIGNAL(signalPlay()),
+            TQ_SLOT(slotPlay()));
+    connect(m_toolBar, TQ_SIGNAL(signalNext()),
+            TQ_SLOT(slotNext()));
+    connect(m_toolBar, TQ_SIGNAL(signalPrev()),
+            TQ_SLOT(slotPrev()));
+    connect(m_toolBar, TQ_SIGNAL(signalClose()),
+            TQ_SLOT(slotClose()));
     
     // -- Minimal texture size (opengl specs) --------------
     
@@ -135,15 +135,15 @@ SlideShowGL::SlideShowGL(const TQValueList<TQPair<TQString, int> >& fileList,
     // --------------------------------------------------
 
     m_timer = new TQTimer();
-    connect(m_timer, TQT_SIGNAL(timeout()),
-            TQT_SLOT(slotTimeOut()));
+    connect(m_timer, TQ_SIGNAL(timeout()),
+            TQ_SLOT(slotTimeOut()));
     m_timer->start(m_timeout, true);
 
     // -- hide cursor when not moved --------------------
 
     m_mouseMoveTimer = new TQTimer;
-    connect(m_mouseMoveTimer, TQT_SIGNAL(timeout()),
-            TQT_SLOT(slotMouseMoveTimeOut()));
+    connect(m_mouseMoveTimer, TQ_SIGNAL(timeout()),
+            TQ_SLOT(slotMouseMoveTimeOut()));
     
     setMouseTracking(true);
     slotMouseMoveTimeOut();
@@ -284,13 +284,13 @@ void SlideShowGL::mousePressEvent(TQMouseEvent *e)
     if (m_endOfShow)
         slotClose();
 
-    if (e->button() == Qt::LeftButton)
+    if (e->button() == TQt::LeftButton)
     {
         m_timer->stop();
         m_toolBar->setPaused(true);
         slotNext();
     }
-    else if (e->button() == Qt::RightButton && m_fileIndex-1 >= 0)
+    else if (e->button() == TQt::RightButton && m_fileIndex-1 >= 0)
     {
         m_timer->stop();
         m_toolBar->setPaused(true);
